@@ -53,12 +53,15 @@ from alchemite_apiclient.model.dataset_calculated_columns import DatasetCalculat
 from alchemite_apiclient.model.dataset_chunk import DatasetChunk
 from alchemite_apiclient.model.dataset_or_data import DatasetOrData
 from alchemite_apiclient.model.dataset_patch import DatasetPatch
+from alchemite_apiclient.model.dataset_query import DatasetQuery
 from alchemite_apiclient.model.dataset_query_request import DatasetQueryRequest
 from alchemite_apiclient.model.dataset_query_request_row_ids import DatasetQueryRequestRowIDs
 from alchemite_apiclient.model.dataset_query_request_sort import DatasetQueryRequestSort
 from alchemite_apiclient.model.dataset_query_response import DatasetQueryResponse
 from alchemite_apiclient.model.dataset_query_response_result import DatasetQueryResponseResult
 from alchemite_apiclient.model.dataset_sharing import DatasetSharing
+from alchemite_apiclient.model.datasets_metadata_filters import DatasetsMetadataFilters
+from alchemite_apiclient.model.datasets_metadata_sort import DatasetsMetadataSort
 from alchemite_apiclient.model.dependent_col_fn_arg_col import DependentColFnArgCol
 from alchemite_apiclient.model.dependent_col_fn_arg_col_weights import DependentColFnArgColWeights
 from alchemite_apiclient.model.dependent_col_fn_arg_constant_sum import DependentColFnArgConstantSum
@@ -120,6 +123,7 @@ from alchemite_apiclient.model.inline_response200 import InlineResponse200
 from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
 from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
 from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
+from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
 from alchemite_apiclient.model.job_patch import JobPatch
 from alchemite_apiclient.model.load_request import LoadRequest
